Enum dot::ArrowShape [−][src]
pub enum ArrowShape {
NoArrow,
Normal(Fill, Side),
Box(Fill, Side),
Crow(Side),
Curve(Side),
ICurve(Fill, Side),
Diamond(Fill, Side),
Dot(Fill),
Inv(Fill, Side),
Tee(Side),
Vee(Side),
}This enumeration represents all possible arrow edge as defined in grapviz documentation.
Variants
No arrow will be displayed
Arrow that ends in a triangle. Basically a normal arrow. NOTE: there is error in official documentation, this supports both fill and side clipping
Arrow ending in a small square box
Crow(Side)Arrow ending in a three branching lines also called crow’s foot
Curve(Side)Arrow ending in a curve
Arrow ending in an inverted curve
Arrow ending in an diamond shaped rectangular shape.
Dot(Fill)Arrow ending in a circle.
Arrow ending in an inverted triangle.
Tee(Side)Arrow ending with a T shaped arrow.
Vee(Side)Arrow ending with a V shaped arrow.
Implementations
impl ArrowShape[src]
impl ArrowShape[src]pub fn none() -> ArrowShape[src]
Constructor which returns no arrow.
pub fn normal() -> ArrowShape[src]
Constructor which returns normal arrow.
pub fn boxed() -> ArrowShape[src]
Constructor which returns a regular box arrow.
pub fn crow() -> ArrowShape[src]
Constructor which returns a regular crow arrow.
pub fn curve() -> ArrowShape[src]
Constructor which returns a regular curve arrow.
pub fn icurve() -> ArrowShape[src]
Constructor which returns an inverted curve arrow.
pub fn diamond() -> ArrowShape[src]
Constructor which returns a diamond arrow.
pub fn dot() -> ArrowShape[src]
Constructor which returns a circle shaped arrow.
pub fn inv() -> ArrowShape[src]
Constructor which returns an inverted triangle arrow.
pub fn tee() -> ArrowShape[src]
Constructor which returns a T shaped arrow.
pub fn vee() -> ArrowShape[src]
Constructor which returns a V shaped arrow.
pub fn to_dot_string(&self) -> String[src]
Function which renders given ArrowShape into a String for displaying.