Enum dot::Fill [−][src]
pub enum Fill {
Open,
Filled,
}Arrow modifier that determines if the shape is empty or filled.
pub enum Fill {
Open,
Filled,
}Arrow modifier that determines if the shape is empty or filled.
impl Copy for Fill[src]impl Eq for Fill[src]impl StructuralEq for Fill[src]impl StructuralPartialEq for Fill[src]impl RefUnwindSafe for Fillimpl Send for Fillimpl Sync for Fillimpl Unpin for Fillimpl UnwindSafe for Fill