Enum dot::Side [−][src]
pub enum Side {
Left,
Right,
Both,
}Arrow modifier that determines if the shape is clipped.
For example Side::Left means only left side is visible.
pub enum Side {
Left,
Right,
Both,
}Arrow modifier that determines if the shape is clipped.
For example Side::Left means only left side is visible.
impl Copy for Side[src]impl Eq for Side[src]impl StructuralEq for Side[src]impl StructuralPartialEq for Side[src]impl RefUnwindSafe for Sideimpl Send for Sideimpl Sync for Sideimpl Unpin for Sideimpl UnwindSafe for Side