Struct dot::Arrow [−][src]
pub struct Arrow {
pub arrows: Vec<ArrowShape>,
}This structure holds all information that can describe an arrow connected to either start or end of an edge.
Fields
arrows: Vec<ArrowShape>Implementations
impl Arrow[src]
impl Arrow[src]pub fn default() -> Arrow[src]
Arrow constructor which returns a default arrow
pub fn none() -> Arrow[src]
Arrow constructor which returns an empty arrow
pub fn normal() -> Arrow[src]
Arrow constructor which returns a regular triangle arrow, without modifiers
pub fn from_arrow(arrow: ArrowShape) -> Arrow[src]
Arrow constructor which returns an arrow created by a given ArrowShape.
pub fn to_dot_string(&self) -> String[src]
Function which converts given arrow into a renderable form.