Struct dot::Arrow [] [src]

pub struct Arrow {
    pub arrows: Vec<ArrowShape>,
}

This structure holds all information that can describe an arrow connected to either start or end of an edge.

Fields

Methods

impl Arrow
[src]

[src]

Arrow constructor which returns a default arrow

[src]

Arrow constructor which returns an empty arrow

[src]

Arrow constructor which returns a regular triangle arrow, without modifiers

[src]

Arrow constructor which returns an arrow created by a given ArrowShape.

[src]

Function which converts given arrow into a renderable form.